@@ -9,6 +9,7 @@ from distutils.version import LooseVersion
 import numpy as np
 from toolz import concat, sliding_window, interleave
 
+from ..compatibility import apply
 from ..core import flatten
 from ..base import tokenize
 from ..highlevelgraph import HighLevelGraph
@@ -238,7 +239,7 @@ def tensordot(lhs, rhs, axes=2):
     if isinstance(axes, Iterable):
         left_axes, right_axes = axes
     else:
-        left_axes = tuple(range(lhs.ndim - 1, lhs.ndim - axes - 1, -1))
+        left_axes = tuple(range(lhs.ndim - axes, lhs.ndim))
         right_axes = tuple(range(0, axes))
 
     if isinstance(left_axes, Integral):
@@ -1292,7 +1293,7 @@ def piecewise(x, condlist, funclist, *args, **kw):
 
 
 @wraps(chunk.coarsen)
-def coarsen(reduction, x, axes, trim_excess=False):
+def coarsen(reduction, x, axes, trim_excess=False, **kwargs):
     if not trim_excess and not all(
         bd % div == 0 for i, div in axes.items() for bd in x.chunks[i]
     ):
@@ -1304,16 +1305,17 @@ def coarsen(reduction, x, axes, trim_excess=False):
 
     name = "coarsen-" + tokenize(reduction, x, axes, trim_excess)
     dsk = {
-        (name,) + key[1:]: (chunk.coarsen, reduction, key, axes, trim_excess)
+        (name,)
+        + key[1:]: (apply, chunk.coarsen, [reduction, key, axes, trim_excess], kwargs)
         for key in flatten(x.__dask_keys__())
     }
     chunks = tuple(
         tuple(int(bd // axes.get(i, 1)) for bd in bds) for i, bds in enumerate(x.chunks)
     )
 
-    dt = reduction(np.empty((1,) * x.ndim, dtype=x.dtype)).dtype
+    meta = reduction(np.empty((1,) * x.ndim, dtype=x.dtype), **kwargs)
     graph = HighLevelGraph.from_collections(name, dsk, dependencies=[x])
-    return Array(graph, name, chunks, dtype=dt)
+    return Array(graph, name, chunks, meta=meta)
 
 
 def split_at_breaks(array, breaks, axis=0):
