@@ -8,6 +8,18 @@ np = pytest.importorskip("numpy")
 
 import dask
 import dask.array as da
+from dask.array.slicing import (
+    _sanitize_index_element,
+    _slice_1d,
+    new_blockdim,
+    sanitize_index,
+    slice_array,
+    take,
+    normalize_index,
+    slicing_plan,
+    make_block_sorted_slices,
+    shuffle_slice,
+)
 from dask.array.slicing import (
     _sanitize_index_element,
     _slice_1d,
@@ -862,27 +874,23 @@ def test_cached_cumsum():
     a = (1, 2, 3, 4)
     x = cached_cumsum(a)
     y = cached_cumsum(a, initial_zero=True)
-    np.testing.assert_array_equal(x, [1, 3, 6, 10])
-    assert x.dtype == np.int64
-    np.testing.assert_array_equal(y, [0, 1, 3, 6, 10])
-    assert y.dtype == np.int64
+    assert x == (1, 3, 6, 10)
+    assert y == (0, 1, 3, 6, 10)
 
 
 def test_cached_cumsum_nan():
     a = (1, np.nan, 3)
     x = cached_cumsum(a)
     y = cached_cumsum(a, initial_zero=True)
-    np.testing.assert_array_equal(x, [1, np.nan, np.nan])
-    assert x.dtype == np.float64
-    np.testing.assert_array_equal(y, [0, 1, np.nan, np.nan])
-    assert y.dtype == np.float64
+    np.testing.assert_equal(x, (1, np.nan, np.nan))
+    np.testing.assert_equal(y, (0, 1, np.nan, np.nan))
 
 
 def test_cached_cumsum_non_tuple():
     a = [1, 2, 3]
-    np.testing.assert_array_equal(cached_cumsum(a), [1, 3, 6])
+    assert cached_cumsum(a) == (1, 3, 6)
     a[1] = 4
-    np.testing.assert_array_equal(cached_cumsum(a), [1, 5, 8])
+    assert cached_cumsum(a) == (1, 5, 8)
 
 
 @pytest.mark.parametrize("params", [(2, 2, 1), (5, 3, 2)])
@@ -906,6 +914,32 @@ def test_gh3579():
     assert_eq(np.arange(10)[::-1], da.arange(10, chunks=3)[::-1])
 
 
+def test_make_blockwise_sorted_slice():
+    x = da.arange(8, chunks=4)
+    index = np.array([6, 0, 4, 2, 7, 1, 5, 3])
+
+    a, b = make_block_sorted_slices(index, x.chunks)
+
+    index2 = np.array([0, 2, 4, 6, 1, 3, 5, 7])
+    index3 = np.array([3, 0, 2, 1, 7, 4, 6, 5])
+    np.testing.assert_array_equal(a, index2)
+    np.testing.assert_array_equal(b, index3)
+
+
+@pytest.mark.filterwarnings("ignore")
+@pytest.mark.parametrize(
+    "size, chunks", [((100, 2), (50, 2)), ((100, 2), (37, 1)), ((100,), (55,))]
+)
+def test_shuffle_slice(size, chunks):
+    x = da.random.randint(0, 1000, size=size, chunks=chunks)
+    index = np.arange(len(x))
+    np.random.shuffle(index)
+
+    a = x[index]
+    b = shuffle_slice(x, index)
+    assert_eq(a, b)
+
+
 @pytest.mark.parametrize("lock", [True, False])
 @pytest.mark.parametrize("asarray", [True, False])
 @pytest.mark.parametrize("fancy", [True, False])
