@@ -8,13 +8,14 @@ import pickle
 import os
 import threading
 import uuid
+from distutils.version import LooseVersion
 
 from toolz import merge, groupby, curry, identity
 from toolz.functoolz import Compose
 
 from .compatibility import is_dataclass, dataclass_fields
 from .context import thread_state
-from .core import flatten, quote, get as simple_get
+from .core import flatten, quote, get as simple_get, literal
 from .hashing import hash_buffer_hex
 from .utils import Dispatch, ensure_dict, apply
 from . import config, local, threaded
@@ -677,6 +678,16 @@ def normalize_seq(seq):
     return type(seq).__name__, list(map(normalize_token, seq))
 
 
+@normalize_token.register(literal)
+def normalize_literal(lit):
+    return "literal", normalize_token(lit())
+
+
+@normalize_token.register(range)
+def normalize_range(r):
+    return list(map(normalize_token, [r.start, r.stop, r.step]))
+
+
 @normalize_token.register(object)
 def normalize_object(o):
     method = getattr(o, "__dask_tokenize__", None)
@@ -739,7 +750,10 @@ def _normalize_function(func):
 @normalize_token.register_lazy("pandas")
 def register_pandas():
     import pandas as pd
-    from dask.dataframe._compat import PANDAS_GT_0240
+
+    # Intentionally not importing PANDAS_GT_0240 from dask.dataframe._compat
+    # to avoid ImportErrors from extra dependencies
+    PANDAS_GT_0240 = LooseVersion(pd.__version__) >= LooseVersion("0.24.0")
 
     @normalize_token.register(pd.Index)
     def normalize_index(ind):
