@@ -6,7 +6,6 @@ from pandas.api.types import is_categorical_dtype, union_categoricals
 from toolz import partition
 
 from .utils import (
-    PANDAS_VERSION,
     is_series_like,
     is_dataframe_like,
     PANDAS_GT_0250,
@@ -15,11 +14,6 @@ from .utils import (
 )
 from ..utils import Dispatch
 
-if PANDAS_VERSION >= "0.23":
-    concat_kwargs = {"sort": False}
-else:
-    concat_kwargs = {}
-
 # ---------------------------------
 # indexing
 # ---------------------------------
@@ -151,7 +145,7 @@ def describe_aggregate(values):
             if name not in names:
                 names.append(name)
 
-    return pd.concat(values, axis=1, **concat_kwargs).reindex(names)
+    return pd.concat(values, axis=1, sort=False).reindex(names)
 
 
 def describe_numeric_aggregate(stats, name=None, is_timedelta_col=False):
@@ -173,7 +167,7 @@ def describe_numeric_aggregate(stats, name=None, is_timedelta_col=False):
         q = q.to_frame()
     part3 = typ([max], index=["max"])
 
-    result = pd.concat([part1, q, part3], **concat_kwargs)
+    result = pd.concat([part1, q, part3], sort=False)
 
     if isinstance(result, pd.Series):
         result.name = name
@@ -263,8 +257,14 @@ def cummax_aggregate(x, y):
 
 
 def assign(df, *pairs):
-    kwargs = dict(partition(2, pairs))
-    return df.assign(**kwargs)
+    # Only deep copy when updating an element
+    # (to avoid modifying the original)
+    pairs = dict(partition(2, pairs))
+    deep = bool(set(pairs) & set(df.columns))
+    df = df.copy(deep=bool(deep))
+    for name, val in pairs.items():
+        df[name] = val
+    return df
 
 
 def unique(x, series_name=None):
@@ -349,7 +349,9 @@ def pivot_count(df, index, columns, values):
 concat_dispatch = Dispatch("concat")
 
 
-def concat(dfs, axis=0, join="outer", uniform=False, filter_warning=True):
+def concat(
+    dfs, axis=0, join="outer", uniform=False, filter_warning=True, ignore_index=False
+):
     """Concatenate, handling some edge cases:
 
     - Unions categoricals between partitions
@@ -364,20 +366,30 @@ def concat(dfs, axis=0, join="outer", uniform=False, filter_warning=True):
         Whether to treat ``dfs[0]`` as representative of ``dfs[1:]``. Set to
         True if all arguments have the same columns and dtypes (but not
         necessarily categories). Default is False.
+    ignore_index : bool, optional
+        Whether to allow index values to be ignored/droped during
+        concatenation. Default is False.
     """
     if len(dfs) == 1:
         return dfs[0]
     else:
         func = concat_dispatch.dispatch(type(dfs[0]))
         return func(
-            dfs, axis=axis, join=join, uniform=uniform, filter_warning=filter_warning
+            dfs,
+            axis=axis,
+            join=join,
+            uniform=uniform,
+            filter_warning=filter_warning,
+            ignore_index=ignore_index,
         )
 
 
 @concat_dispatch.register((pd.DataFrame, pd.Series, pd.Index))
-def concat_pandas(dfs, axis=0, join="outer", uniform=False, filter_warning=True):
+def concat_pandas(
+    dfs, axis=0, join="outer", uniform=False, filter_warning=True, ignore_index=False
+):
     if axis == 1:
-        return pd.concat(dfs, axis=axis, join=join, **concat_kwargs)
+        return pd.concat(dfs, axis=axis, join=join, sort=False)
 
     # Support concatenating indices along axis 0
     if isinstance(dfs[0], pd.Index):
@@ -448,7 +460,7 @@ def concat_pandas(dfs, axis=0, join="outer", uniform=False, filter_warning=True)
                 cat_mask = pd.concat(
                     [(df.dtypes == "category").to_frame().T for df in dfs3],
                     join=join,
-                    **concat_kwargs
+                    sort=False,
                 ).any()
 
         if cat_mask.any():
@@ -457,7 +469,7 @@ def concat_pandas(dfs, axis=0, join="outer", uniform=False, filter_warning=True)
             out = pd.concat(
                 [df[df.columns.intersection(not_cat)] for df in dfs3],
                 join=join,
-                **concat_kwargs
+                sort=False,
             )
             temp_ind = out.index
             for col in cat_mask.index.difference(not_cat):
@@ -489,7 +501,7 @@ def concat_pandas(dfs, axis=0, join="outer", uniform=False, filter_warning=True)
                 warnings.simplefilter("ignore", RuntimeWarning)
                 if filter_warning:
                     warnings.simplefilter("ignore", FutureWarning)
-                out = pd.concat(dfs3, join=join, **concat_kwargs)
+                out = pd.concat(dfs3, join=join, sort=False)
     else:
         if is_categorical_dtype(dfs2[0].dtype):
             if ind is None:
@@ -498,7 +510,7 @@ def concat_pandas(dfs, axis=0, join="outer", uniform=False, filter_warning=True)
         with warnings.catch_warnings():
             if filter_warning:
                 warnings.simplefilter("ignore", FutureWarning)
-            out = pd.concat(dfs2, join=join, **concat_kwargs)
+            out = pd.concat(dfs2, join=join, sort=False)
     # Re-add the index if needed
     if ind is not None:
         out.index = ind
