@@ -8,7 +8,6 @@ import numpy as np
 import pandas as pd
 
 from .core import DataFrame, Series, _Frame, _concat, map_partitions
-from . import methods
 
 from .. import base, config
 from ..base import tokenize, compute, compute_as_if_collection
@@ -16,7 +15,7 @@ from ..delayed import delayed
 from ..highlevelgraph import HighLevelGraph
 from ..sizeof import sizeof
 from ..utils import digit, insert, M
-from .utils import series_type_like_df
+from .utils import hash_object_dispatch, group_split_dispatch
 
 
 def set_index(
@@ -35,11 +34,19 @@ def set_index(
     if isinstance(index, Series) and index._name == df.index._name:
         return df
     if isinstance(index, (DataFrame, tuple, list)):
-        raise NotImplementedError(
-            "Dask dataframe does not yet support multi-indexes.\n"
-            "You tried to index with this index: %s\n"
-            "Indexes must be single columns only." % str(index)
-        )
+        # Accept ["a"], but not [["a"]]
+        if (
+            isinstance(index, list)
+            and len(index) == 1
+            and not isinstance(index[0], list)  # if index = [["a"]], leave it that way
+        ):
+            index = index[0]
+        else:
+            raise NotImplementedError(
+                "Dask dataframe does not yet support multi-indexes.\n"
+                "You tried to index with this index: %s\n"
+                "Indexes must be single columns only." % str(index)
+            )
 
     if npartitions == "auto":
         repartition = True
@@ -60,7 +67,7 @@ def set_index(
             parts = df.to_delayed(optimize_graph=False)
             sizes = [delayed(sizeof)(part) for part in parts]
         else:
-            index2, = base.optimize(index2)
+            (index2,) = base.optimize(index2)
             sizes = []
 
         divisions = index2._repartition_quantiles(npartitions, upsample=upsample)
@@ -91,6 +98,10 @@ def set_index(
 
         mins = remove_nans(mins)
         maxes = remove_nans(maxes)
+        if pd.api.types.is_categorical_dtype(index2.dtype):
+            dtype = index2.dtype
+            mins = pd.Categorical(mins, dtype=dtype).codes.tolist()
+            maxes = pd.Categorical(maxes, dtype=dtype).codes.tolist()
 
         if (
             mins == sorted(mins)
@@ -171,8 +182,22 @@ def set_partition(
     shuffle
     partd
     """
-    divisions = series_type_like_df(df)(divisions)
-    meta = series_type_like_df(df)([0])
+    meta = df._meta._constructor_sliced([0])
+    if isinstance(divisions, tuple):
+        # pd.isna considers tuples to be scalars. Convert to a list.
+        divisions = list(divisions)
+
+    if np.isscalar(index):
+        dtype = df[index].dtype
+    else:
+        dtype = index.dtype
+
+    if pd.isna(divisions).any() and pd.api.types.is_integer_dtype(dtype):
+        # Can't construct a Series[int64] when any / all of the divisions are NaN.
+        divisions = df._meta._constructor_sliced(divisions)
+    else:
+        divisions = df._meta._constructor_sliced(divisions, dtype=dtype)
+
     if np.isscalar(index):
         partitions = df[index].map_partitions(
             set_partitions_pre, divisions=divisions, meta=meta
@@ -191,6 +216,7 @@ def set_partition(
         npartitions=len(divisions) - 1,
         shuffle=shuffle,
         compute=compute,
+        ignore_index=True,
     )
 
     if np.isscalar(index):
@@ -236,7 +262,7 @@ def shuffle(df, index, shuffle=None, npartitions=None, max_branch=32, compute=No
     partitions = index.map_partitions(
         partitioning_index,
         npartitions=npartitions or df.npartitions,
-        meta=series_type_like_df(df)([0]),
+        meta=df._meta._constructor_sliced([0]),
         transform_divisions=False,
     )
     df2 = df.assign(_partitions=partitions)
@@ -255,8 +281,8 @@ def shuffle(df, index, shuffle=None, npartitions=None, max_branch=32, compute=No
 
 def rearrange_by_divisions(df, column, divisions, max_branch=None, shuffle=None):
     """ Shuffle dataframe so that column separates along divisions """
-    divisions = series_type_like_df(df)(divisions)
-    meta = series_type_like_df(df)([0])
+    divisions = df._meta._constructor_sliced(divisions)
+    meta = df._meta._constructor_sliced([0])
     # Assign target output partitions to every row
     partitions = df[column].map_partitions(
         set_partitions_pre, divisions=divisions, meta=meta
@@ -276,13 +302,21 @@ def rearrange_by_divisions(df, column, divisions, max_branch=None, shuffle=None)
 
 
 def rearrange_by_column(
-    df, col, npartitions=None, max_branch=None, shuffle=None, compute=None
+    df,
+    col,
+    npartitions=None,
+    max_branch=None,
+    shuffle=None,
+    compute=None,
+    ignore_index=False,
 ):
     shuffle = shuffle or config.get("shuffle", None) or "disk"
     if shuffle == "disk":
         return rearrange_by_column_disk(df, col, npartitions, compute=compute)
     elif shuffle == "tasks":
-        return rearrange_by_column_tasks(df, col, max_branch, npartitions)
+        return rearrange_by_column_tasks(
+            df, col, max_branch, npartitions, ignore_index=ignore_index
+        )
     else:
         raise NotImplementedError("Unknown shuffle method %s" % shuffle)
 
@@ -295,6 +329,7 @@ class maybe_buffered_partd(object):
     def __init__(self, buffer=True, tempdir=None):
         self.tempdir = tempdir or config.get("temporary_directory", None)
         self.buffer = buffer
+        self.compression = config.get("dataframe.shuffle-compression", None)
 
     def __reduce__(self):
         if self.tempdir:
@@ -305,10 +340,26 @@ class maybe_buffered_partd(object):
     def __call__(self, *args, **kwargs):
         import partd
 
+        try:
+            partd_compression = (
+                getattr(partd.compressed, self.compression)
+                if self.compression
+                else None
+            )
+        except AttributeError:
+            raise ImportError(
+                "Not able to import and load {0} as compression algorithm."
+                "Please check if the library is installed and supported by Partd.".format(
+                    self.compression
+                )
+            )
         if self.tempdir:
             file = partd.File(dir=self.tempdir)
         else:
             file = partd.File()
+        # Envelope partd file with compression, if set and available
+        if partd_compression:
+            file = partd_compression(file)
         if self.buffer:
             return partd.PandasBlocks(partd.Buffer(partd.Dict(), file))
         else:
@@ -369,7 +420,9 @@ def rearrange_by_column_disk(df, column, npartitions=None, compute=False):
     return DataFrame(graph, name, df._meta, divisions)
 
 
-def rearrange_by_column_tasks(df, column, max_branch=32, npartitions=None):
+def rearrange_by_column_tasks(
+    df, column, max_branch=32, npartitions=None, ignore_index=False
+):
     """ Order divisions of DataFrame so that all values within column align
 
     This enacts a task-based shuffle.  It contains most of the tricky logic
@@ -451,6 +504,7 @@ def rearrange_by_column_tasks(df, column, max_branch=32, npartitions=None):
                 stage - 1,
                 k,
                 n,
+                ignore_index,
             )
             for inp in inputs
         }
@@ -477,6 +531,7 @@ def rearrange_by_column_tasks(df, column, max_branch=32, npartitions=None):
                     )
                     for j in range(k)
                 ],
+                ignore_index,
             )
             for inp in inputs
         }
@@ -498,7 +553,12 @@ def rearrange_by_column_tasks(df, column, max_branch=32, npartitions=None):
         token = tokenize(df2, npartitions)
 
         dsk = {
-            ("repartition-group-" + token, i): (shuffle_group_2, k, column)
+            ("repartition-group-" + token, i): (
+                shuffle_group_2,
+                k,
+                column,
+                ignore_index,
+            )
             for i, k in enumerate(df2.__dask_keys__())
         }
         for p in range(npartitions):
@@ -543,7 +603,7 @@ def partitioning_index(df, npartitions):
     partitions : ndarray
         An array of int64 values mapping each record to a partition.
     """
-    return methods.hash_df(df) % int(npartitions)
+    return hash_object_dispatch(df, index=False) % int(npartitions)
 
 
 def barrier(args):
@@ -563,12 +623,14 @@ def set_partitions_pre(s, divisions):
     return partitions
 
 
-def shuffle_group_2(df, col):
+def shuffle_group_2(df, col, ignore_index):
     if not len(df):
         return {}, df
     ind = df[col].astype(np.int64)
     n = ind.max() + 1
-    result2 = methods.group_split(df, ind.values.view(np.int64), n)
+    result2 = group_split_dispatch(
+        df, ind.values.view(np.int64), n, ignore_index=ignore_index
+    )
     return result2, df.iloc[:0]
 
 
@@ -580,7 +642,7 @@ def shuffle_group_get(g_head, i):
         return head
 
 
-def shuffle_group(df, col, stage, k, npartitions):
+def shuffle_group(df, col, stage, k, npartitions, ignore_index):
     """ Splits dataframe into groups
 
     The group is determined by their final partition, and which stage we are in
@@ -609,7 +671,7 @@ def shuffle_group(df, col, stage, k, npartitions):
     if col == "_partitions":
         ind = df[col]
     else:
-        ind = methods.hash_df(df)
+        ind = hash_object_dispatch(df, index=False)
 
     c = ind.values
     typ = np.min_scalar_type(npartitions * 2)
@@ -618,7 +680,7 @@ def shuffle_group(df, col, stage, k, npartitions):
     np.floor_divide(c, k ** stage, out=c)
     np.mod(c, k, out=c)
 
-    return methods.group_split(df, c.astype(np.int64), k)
+    return group_split_dispatch(df, c.astype(np.int64), k, ignore_index=ignore_index)
 
 
 def shuffle_group_3(df, col, npartitions, p):
