@@ -12,7 +12,7 @@ from copy import copy
 
 import dask
 import dask.dataframe as dd
-from dask.dataframe._compat import tm, PANDAS_GT_100, assert_categorical_equal
+from dask.dataframe._compat import tm, assert_categorical_equal
 from dask import delayed
 from dask.base import compute_as_if_collection
 from dask.dataframe.shuffle import (
@@ -142,9 +142,6 @@ def test_partitioning_index():
     assert len(np.unique(res)) > 1
 
 
-@pytest.mark.xfail(
-    PANDAS_GT_100, reason="https://github.com/pandas-dev/pandas/issues/30887"
-)
 def test_partitioning_index_categorical_on_values():
     df = pd.DataFrame({"a": list(string.ascii_letters), "b": [1, 2, 3, 4] * 13})
     df.a = df.a.astype("category")
@@ -393,8 +390,9 @@ def test_set_index_consistent_divisions():
 
     ctx = mp.get_context("spawn")
     pool = ctx.Pool(processes=8)
-    results = [pool.apply_async(_set_index, (ddf, "x")) for _ in range(100)]
-    divisions_set = set(result.get() for result in results)
+    with pool:
+        results = [pool.apply_async(_set_index, (ddf, "x")) for _ in range(100)]
+        divisions_set = set(result.get() for result in results)
     assert len(divisions_set) == 1
 
 
